@@ -37,7 +37,6 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gBrowser = null;
 var gAltPluginWizard = null;
 
 altPluginWizard.prototype.pluginUsed = function(pluginElement){
@@ -71,7 +70,7 @@ altPluginWizard.prototype.tabSelected = function(aEvent){
     var iconAltPlugins = document.getElementById("iconAltPlugins");
     iconAltPlugins.hidden = true;
     var menuAltPlugins = document.getElementById("menuAltPlugins");
-    menuAltPlugins.disabled = true;
+    menuAltPlugins.disabled = false;
   }
 }
 
@@ -87,14 +86,15 @@ function altPluginWizard(){
 
 function openPluginFinder(contentMimeArray){
     
+  var iconAltPlugins = document.getElementById("iconAltPlugins");
   window.openDialog("chrome://ubufox/content/pluginAlternativeOverlay.xul",
                    "PFSWindow", "chrome,centerscreen,resizable=yes",
-                   {plugins: contentMimeArray, browser: gBrowser.selectedBrowser});
+                   {plugins: contentMimeArray, browser: gBrowser.selectedBrowser, pluginsOnTab: !iconAltPlugins.hidden});
 }
 
+
 window.addEventListener("load", function() {
 
-  gBrowser = document.getElementById("content");  
   gAltPluginWizard = new altPluginWizard();
   gBrowser.tabContainer.addEventListener("TabSelect", gAltPluginWizard.tabSelected, false);
   gBrowser.addEventListener("DOMContentLoaded", gAltPluginWizard.domContentLoaded, false);
